# -*- coding: utf-8 -*-
from robot.libraries.BuiltIn import BuiltIn


class Library(object):
    """This library provides RobotFramework resources for openMairie based apps."""

    def __init__(self):
        """Init."""
        self.import_library_resources()

    def import_library_resources(self):
        """Import openMairieRobotFramework user keywords."""
        BuiltIn().import_resource('openmairie/robotframework/om_resources.robot')
        #
        BuiltIn().import_resource('openmairie/robotframework/formulaire.robot')
        BuiltIn().import_resource('openmairie/robotframework/menu.robot')
        BuiltIn().import_resource('openmairie/robotframework/module_gen.robot')
        BuiltIn().import_resource('openmairie/robotframework/module_import.robot')
        BuiltIn().import_resource('openmairie/robotframework/module_reqmo.robot')
        BuiltIn().import_resource('openmairie/robotframework/module_sig_interne.robot')
        BuiltIn().import_resource('openmairie/robotframework/navigation.robot')
        BuiltIn().import_resource('openmairie/robotframework/pdf.robot')
        BuiltIn().import_resource('openmairie/robotframework/tableau.robot')
        BuiltIn().import_resource('openmairie/robotframework/utils.robot')
        #
        BuiltIn().import_resource('openmairie/robotframework/om_collectivite.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_droit.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_etat.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_lettretype.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_logo.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_parametre.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_profil.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_requete.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_sousetat.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_utilisateur.robot')
        BuiltIn().import_resource('openmairie/robotframework/om_widget.robot')



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import os


version = '4.8.10002'

here = os.path.abspath(os.path.dirname(__file__))

def read_file(*pathes):
    path = os.path.join(here, *pathes)
    if os.path.isfile(path):
        with open(path, 'r') as desc_file:
            return desc_file.read()
    else:
        return ''

desc_files = (('README.rst',), ('docs', 'CHANGES.rst'),
                ('docs', 'CONTRIBUTORS.rst'))

long_description = '\n\n'.join([read_file(*pathes) for pathes in desc_files])

install_requires=['setuptools']


setup(name='openmairie.robotframework',
      version=version,
      description="RobotFramework Library for functional testing openMairie Framework based apps",
      long_description=long_description,
      platforms = ["any"],
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        ],
      keywords="openMairie RobotFramework",
      author="openMairie",
      author_email="contact@openmairie.org",
      url="https://github.com/openmairie/openmairie.robotframework/",
      license="GPL",
      packages=find_packages("src"),
      package_dir = {"": "src"},
      namespace_packages=["openmairie"],
      include_package_data=True,
      zip_safe=False,
      install_requires=install_requires,
      entry_points="""
      # -*- Entry points: -*-
      """,
      )

# vim:set et sts=4 ts=4 tw=80:
